Python 3 library for dealing with numeric values with uncertainties and upper/lower limits, which we call _rich values_. With it, one can import rich values written in plain text documents in an easily readable format, operate with them propagating the uncertainties automatically, and export them in the same formatting style as the import.

This library require the modules `copy`, `math`, and `itertools`, from the Python’s standard library, and also the libraries NumPy and Pandas.

An user guide is available in the GitHub repository: [https://github.com/andresmegias/richvalues](https://github.com/andresmegias/richvalues)
